#define XERR
#include "options.ih"

void Options::lastCase(string const &value)
{
    xerr("value: " << value);
    d_lastCase = stoul(value);
}

